==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/mn/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Энэ хэрэглэгч нэвтрэх эрхтэй',
    'activated_disabled_help_text' => 'Та өөрийн дансны идэвхжүүлэх статусыг засах боломжгүй.',
    'assets_user'       => 'Нэр:',
    'bulk_update_warn'	=> 'Та: user_count хэрэглэгчдийн шинж чанарыг засах гэж байна. Энэ маягтыг ашиглан өөрийн хэрэглэгчийн атрибутуудыг өөрчлөх боломжгүй гэдгийг анхаарна уу. Мөн өөрийн хэрэглэгчдэд тус бүрд засвар хийлгэх ёстой.',
    'bulk_update_help'	=> 'Энэ маягт нь олон хэрэглэгчийг нэгэн зэрэг шинэчлэх боломжийг олгоно. Зөвхөн өөрчлөх шаардлагатай талбаруудыг бөглөөрэй. Хоосон үлдсэн талбарууд өөрчлөгдөхгүй хэвээр үлдэнэ.',
    'current_assets'    => 'Одоогоор ашиглагдаж буй активууд энэ хэрэглэгчийг шалгасан байна',
    'clone'             => 'Clone Хэрэглэгч',
    'contact_user'      => 'Холбоо барих нэр',
    'edit'              => 'Хэрэглэгчийг засварлах',
    'filetype_info'     => 'Зөвшөөрөгдсөн filetypes нь png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Түүх: нэр',
	'info'				=> 'Мэдээлэл',
    'restore_user'		=> 'Тэднийг сэргээхийн тулд энд дарна уу.',
    'last_login'        => 'Сүүлчийн Нэвтрэх',
    'ldap_config_text'  => 'LDAP тохиргооны тохиргоог Админ> Тохиргоо гэж олж болно. (Заавал биш) сонгосон байршлыг бүх импортлогчдын хувьд тохируулах болно.',
    'print_assigned'    => 'Бүх хуваарилагдсан хөрөнгийг хэвлэх',
    'software_user'     => 'Програм хангамж: нэр',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Хэрэглэгч: нэрийг харах',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Таны одоогийн админ тохиргоо нь хоёр хүчин зүйлийн баталгаажуулалтыг сонгохыг зөвшөөрдөг.',
    'two_factor_enrolled' => '2FA төхөөрөмжийг бүртгүүлсэн',
    'two_factor_active'   => '2FA идэвхтэй',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/mn/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Энэ хэрэглэгч нэвтрэх эрхтэй',
    'activated_disabled_help_text' => 'Та өөрийн дансны идэвхжүүлэх статусыг засах боломжгүй.',
    'assets_user'       => 'Нэр:',
    'bulk_update_warn'	=> 'Та: user_count хэрэглэгчдийн шинж чанарыг засах гэж байна. Энэ маягтыг ашиглан өөрийн хэрэглэгчийн атрибутуудыг өөрчлөх боломжгүй гэдгийг анхаарна уу. Мөн өөрийн хэрэглэгчдэд тус бүрд засвар хийлгэх ёстой.',
    'bulk_update_help'	=> 'Энэ маягт нь олон хэрэглэгчийг нэгэн зэрэг шинэчлэх боломжийг олгоно. Зөвхөн өөрчлөх шаардлагатай талбаруудыг бөглөөрэй. Хоосон үлдсэн талбарууд өөрчлөгдөхгүй хэвээр үлдэнэ.',
    'current_assets'    => 'Одоогоор ашиглагдаж буй активууд энэ хэрэглэгчийг шалгасан байна',
    'clone'             => 'Clone Хэрэглэгч',
    'contact_user'      => 'Холбоо барих нэр',
    'edit'              => 'Хэрэглэгчийг засварлах',
    'filetype_info'     => 'Зөвшөөрөгдсөн filetypes нь png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Түүх: нэр',
    'info'				=> 'Мэдээлэл',
    'restore_user'		=> 'Тэднийг сэргээхийн тулд энд дарна уу.',
    'last_login'        => 'Сүүлчийн Нэвтрэх',
    'ldap_config_text'  => 'LDAP тохиргооны тохиргоог Админ> Тохиргоо гэж олж болно. (Заавал биш) сонгосон байршлыг бүх импортлогчдын хувьд тохируулах болно.',
    'print_assigned'    => 'Бүх хуваарилагдсан хөрөнгийг хэвлэх',
    'software_user'     => 'Програм хангамж: нэр',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Хэрэглэгч: нэрийг харах',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Таны одоогийн админ тохиргоо нь хоёр хүчин зүйлийн баталгаажуулалтыг сонгохыг зөвшөөрдөг.',
    'two_factor_enrolled' => '2FA төхөөрөмжийг бүртгүүлсэн',
    'two_factor_active'   => '2FA идэвхтэй',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
